@@ -1722,7 +1722,7 @@ __imlib_GetBlendFunction(ImlibOp op, char blend, char merge_alpha, char rgb_src,
       return NULL;
 
 #ifdef DO_MMX_ASM
-   do_mmx = !!(__imlib_get_cpuid() & CPUID_MMX);
+   do_mmx = ! !(__imlib_get_cpuid() & CPUID_MMX);
 #elif DO_AMD64_ASM
    do_mmx = 1;                  // instruction set is always present
 #endif
@@ -1730,7 +1730,7 @@ __imlib_GetBlendFunction(ImlibOp op, char blend, char merge_alpha, char rgb_src,
       blend = 0;
    if (blend && cm && rgb_src && (A_CMOD(cm, 0xff) == 0))
       return NULL;
-   return ibfuncs[!!do_mmx][opi][!!cm][!!merge_alpha][!!rgb_src][!!blend];
+   return ibfuncs[! !do_mmx][opi][! !cm][! !merge_alpha][! !rgb_src][! !blend];
 }
 
 void
@@ -1799,7 +1799,7 @@ __imlib_BlendImageToImage(ImlibImage * im_src, ImlibImage * im_dst,
 
    if ((!(im_src->data)) && (im_src->loader) && (im_src->loader->load))
       im_src->loader->load(im_src, NULL, 0, 1);
-   if ((!(im_dst->data)) && (im_dst->loader) && (im_src->loader->load))
+   if ((!(im_dst->data)) && (im_dst->loader) && (im_dst->loader->load))
       im_dst->loader->load(im_dst, NULL, 0, 1);
    if (!im_src->data)
       return;
