@@ -15,8 +15,6 @@ static DATA8        rtab[256], gtab[256], btab[256];
 static void
 Tmp_HandleXError(Display * d, XErrorEvent * ev)
 {
-   d = NULL;
-   ev = NULL;
    _x_err = 1;
 }
 
@@ -528,17 +526,15 @@ __imlib_GrabDrawableToRGBA(DATA32 * data, int ox, int oy, int ow, int oh,
    char                is_pixmap = 0, created_mask = 0, is_shm = 0, is_mshm = 0;
    char                domask;
    int                 i;
-   int                 src_x, src_y, src_w, src_h, origw, origh;
+   int                 src_x, src_y, src_w, src_h;
    int                 width, height, clipx, clipy;
    XShmSegmentInfo     shminfo, mshminfo;
    XImage             *xim, *mxim;
    XColor              cols[256];
 
    domask = (pdomask) ? *pdomask : 0;
-   /* FIXME: oh isnt used - i wonder if there's a bug looming... */
+   /* FIXME: oh isn't used - i wonder if there's a bug looming... */
    oh = 0;
-   origw = w;
-   origh = h;
    if (grab)
       XGrabServer(d);
    XSync(d, False);
@@ -668,7 +664,7 @@ __imlib_GrabDrawableToRGBA(DATA32 * data, int ox, int oy, int ow, int oh,
    if (x_does_shm)
      {
         xim = __imlib_ShmGetXImage(d, v, p, xatt.depth, x, y, w, h, &shminfo);
-        is_shm = xim != NULL;
+        is_shm = ! !xim;
      }
    if (!xim)
       xim = XGetImage(d, p, x, y, w, h, 0xffffffff, ZPixmap);
@@ -683,7 +679,7 @@ __imlib_GrabDrawableToRGBA(DATA32 * data, int ox, int oy, int ow, int oh,
    if ((m) && (domask))
      {
         mxim = __imlib_ShmGetXImage(d, v, m, 1, 0, 0, w, h, &mshminfo);
-        is_mshm = mxim != NULL;
+        is_mshm = ! !mxim;
         if (!mxim)
            mxim = XGetImage(d, m, 0, 0, w, h, 0xffffffff, ZPixmap);
      }
