@@ -7,7 +7,7 @@
 #include <ctype.h>
 #include <errno.h>
 #ifdef BUILD_X11
-# include <X11/Xlib.h>
+#include <X11/Xlib.h>
 #endif
 #include "image.h"
 #include "file.h"
@@ -142,8 +142,7 @@ __imlib_ProduceImage(void)
 {
    ImlibImage         *im;
 
-   im = malloc(sizeof(ImlibImage));
-   memset(im, 0, sizeof(ImlibImage));
+   im = calloc(1, sizeof(ImlibImage));
    im->data = NULL;
    im->file = NULL;
    im->real_file = NULL;
@@ -393,8 +392,7 @@ __imlib_ProduceImagePixmap(void)
 {
    ImlibImagePixmap   *ip;
 
-   ip = malloc(sizeof(ImlibImagePixmap));
-   memset(ip, 0, sizeof(ImlibImagePixmap));
+   ip = calloc(1, sizeof(ImlibImagePixmap));
    ip->display = NULL;
    ip->visual = NULL;
    ip->image = NULL;
@@ -490,7 +488,7 @@ __imlib_AddImagePixmapToCache(ImlibImagePixmap * ip)
    pixmaps = ip;
 }
 
-/* remove a pixmap cache struct fromt he pixmap cache */
+/* remove a pixmap cache struct from the pixmap cache */
 void
 __imlib_RemoveImagePixmapFromCache(ImlibImagePixmap * ip)
 {
@@ -591,7 +589,7 @@ __imlib_ProduceLoader(char *file)
    return l;
 }
 
-/* list all the filenames of loaders  int he system loaders dir and the user */
+/* list all the filenames of loaders  in the system loaders dir and the user */
 /* loader dir */
 char              **
 __imlib_ListLoaders(int *num_ret)
@@ -676,8 +674,7 @@ __imlib_TrimLoaderList(char **list, int *num)
         if (list[i])
            free(list[i]);
      }
-   if (list)
-      free(list);
+   free(list);
    *num = size;
    return ret;
 }
@@ -824,7 +821,7 @@ __imlib_FindBestLoaderForFile(const char *file, int for_save)
    extension = __imlib_FileExtension(rfile);
    free(rfile);
    /* change the extensiont o all lower case as all "types" are listed as */
-   /* lower case strings fromt he loader that represent all the possible */
+   /* lower case strings from the loader that represent all the possible */
    /* extensions that file format could have */
    lower = extension;
    while (*lower)
@@ -842,7 +839,7 @@ __imlib_FindBestLoaderForFile(const char *file, int for_save)
    /* systematically go from most recently used to least recently used */
    /* loader until one succeeds - or none are left and all have failed */
    /* and only if all fail does the laod fail. the lao9der that does */
-   /* succeed gets it way tot he head of the list so it's going */
+   /* succeed gets it way to the head of the list so it's going */
    /* to be used first next time in this search mechanims - this */
    /* assumes you tend to laod a few image types and ones generally */
    /* of the same format */
@@ -890,7 +887,7 @@ __imlib_FindBestLoaderForFileFormat(const char *file, char *format,
      {
         extension = __imlib_FileExtension(file);
         /* change the extension to all lower case as all "types" are listed as */
-        /* lower case strings fromt he loader that represent all the possible */
+        /* lower case strings from the loader that represent all the possible */
         /* extensions that file format could have */
         if (extension)
           {
@@ -975,7 +972,7 @@ __imlib_LoadImage(const char *file, ImlibProgressFunction progress,
       return NULL;
    /* see if we already have the image cached */
    im = __imlib_FindCachedImage(file);
-   /* if we found a cached image and we shoudl always check that it is */
+   /* if we found a cached image and we should always check that it is */
    /* accurate to the disk conents if they changed since we last loaded */
    /* and that it is still a valid image */
    if ((im) && (IMAGE_IS_VALID(im)))
@@ -986,7 +983,7 @@ __imlib_LoadImage(const char *file, ImlibProgressFunction progress,
 
              current_modified_time = __imlib_FileModDate(file);
              /* if the file on disk is newer than the cached one */
-             if (current_modified_time > im->moddate)
+             if (current_modified_time != im->moddate)
                {
                   /* invalidate image */
                   SET_FLAG(im->flags, F_INVALID);
@@ -1028,7 +1025,7 @@ __imlib_LoadImage(const char *file, ImlibProgressFunction progress,
    if (best_loader)
       loader_ret =
          best_loader->load(im, progress, progress_granularity, immediate_load);
-   /* width is still 0 - the loader didnt manage to do anything */
+   /* width is still 0 - the loader didn't manage to do anything */
    if (im->w == 0)
      {
         ImlibLoader        *l, *previous_l = NULL;
