@@ -13,7 +13,7 @@
 
 # ifndef RTLD_LOCAL
 #  define RTLD_LOCAL 0
-#  warning "your crap box doesnt define RTLD_LOCAL !?"
+#  warning "your crap box doesn't define RTLD_LOCAL !?"
 # endif
 
 typedef struct _imlibimage              ImlibImage;
@@ -188,4 +188,8 @@ __hidden void              __imlib_SaveImage(ImlibImage *im, const char *file,
 # define SET_FLAG(flags, f) ((flags) |= (f))
 # define UNSET_FLAG(flags, f) ((flags) &= (~f))
 
+# define IMAGE_DIMENSIONS_OK(w, h) \
+   ( ((w) > 0) && ((h) > 0) && \
+     ((unsigned long long)(w) * (unsigned long long)(h) <= (1ULL << 29) - 1) )
+
 #endif
