@@ -3,7 +3,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/extensions/XShm.h>
-#endif
 #include "colormod.h"
 #include "image.h"
 #include "scale.h"
@@ -16,7 +15,9 @@
 #include "rend.h"
 #include "rotate.h"
 
-#ifdef BUILD_X11
+/* The maximum pixmap dimension is 65535. */
+/* However, for now, use 46340 (46340^2 < 2^31) to avoid buffer overflow issues. */
+#define X_MAX_DIM 46340
 
 /* size of the lines per segment we scale / render at a time */
 #define LINESIZE 16
@@ -96,7 +97,7 @@ __imlib_RenderGetPixel(Display * d, Drawable w, Visual * v, Colormap cm,
           }
         for (i = 31; i >= 0; i--)
           {
-             if (rm >= (1 << i))
+             if (rm >= (1U << i))
                {
                   rshift = i - 7;
                   break;
@@ -104,7 +105,7 @@ __imlib_RenderGetPixel(Display * d, Drawable w, Visual * v, Colormap cm,
           }
         for (i = 31; i >= 0; i--)
           {
-             if (gm >= (1 << i))
+             if (gm >= (1U << i))
                {
                   gshift = i - 7;
                   break;
@@ -112,7 +113,7 @@ __imlib_RenderGetPixel(Display * d, Drawable w, Visual * v, Colormap cm,
           }
         for (i = 31; i >= 0; i--)
           {
-             if (bm >= (1 << i))
+             if (bm >= (1U << i))
                {
                   bshift = i - 7;
                   break;
@@ -135,19 +136,16 @@ __imlib_RenderGetPixel(Display * d, Drawable w, Visual * v, Colormap cm,
    return 0;
 }
 
-__hidden void
-                    __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
-                                           XImage * xim, Visual * v,
-                                           Context * ct);
-
-void
+static void
 __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
                        XImage * xim, Visual * v, Context * ct)
 {
-   unsigned int        x, y, r, g, b, val, hh;
+   int                 x, y, hh;
+   unsigned int        r, g, b, val;
    unsigned int        rmask, gmask, bmask;
    int                 i, rshift, gshift, bshift;
-   const DATA8         _dither_88[8][8] = {
+
+   static const DATA8  _dither_88[8][8] = {
       {0, 32, 8, 40, 2, 34, 10, 42},
       {48, 16, 56, 24, 50, 18, 58, 26},
       {12, 44, 4, 36, 14, 46, 6, 38},
@@ -187,7 +185,7 @@ __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
    bshift = 0;
    for (i = 31; i >= 0; i--)
      {
-        if (rmask >= (1 << i))
+        if (rmask >= (1U << i))
           {
              rshift = i - 7;
              break;
@@ -195,7 +193,7 @@ __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
      }
    for (i = 31; i >= 0; i--)
      {
-        if (gmask >= (1 << i))
+        if (gmask >= (1U << i))
           {
              gshift = i - 7;
              break;
@@ -203,7 +201,7 @@ __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
      }
    for (i = 31; i >= 0; i--)
      {
-        if (bmask >= (1 << i))
+        if (bmask >= (1U << i))
           {
              bshift = i - 7;
              break;
@@ -235,6 +233,21 @@ __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
      }
 }
 
+static Display     *disp = NULL;
+static GC           gc = NULL;
+static GC           gcm = NULL;
+static int          last_depth = 0;
+
+void
+__imlib_RenderDisconnect(Display * d)
+{
+   if (d != disp)
+      return;
+   disp = NULL;
+   gc = gcm = NULL;
+   last_depth = 0;
+}
+
 void
 __imlib_RenderImage(Display * d, ImlibImage * im,
                     Drawable w, Drawable m,
@@ -248,10 +261,6 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
    Context            *ct;
    DATA32             *buf = NULL, *pointer = NULL, *back = NULL;
    int                 y, h, hh, jump;
-   static Display     *disp = NULL;
-   static int          last_depth = 0;
-   static GC           gc = 0;
-   static GC           gcm = 0;
    XGCValues           gcv;
    ImlibScaleInfo     *scaleinfo = NULL;
    int                 psx, psy, psw, psh;
@@ -259,7 +268,10 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
    ImlibRGBAFunction   rgbaer;
    ImlibMaskFunction   masker = NULL;
    ImlibBlendFunction  blender = NULL;
+
+#ifdef DO_MMX_ASM
    int                 do_mmx;
+#endif
 
    blender = __imlib_GetBlendFunction(op, 1, 0,
                                       (!(im->flags & F_HAS_ALPHA)), NULL);
@@ -270,8 +282,8 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
    /* if the input rect size < 0 dont render either */
    if ((sw <= 0) || (sh <= 0))
       return;
-   /* if the output is too big (8k arbitary limit here) dont bother */
-   if ((abs(dw) > 8192) || (abs(dh) > 8192))
+   /* if the output is too big (8k arbitrary limit here) dont bother */
+   if ((abs(dw) > X_MAX_DIM) || (abs(dh) > X_MAX_DIM))
       return;
    /* clip the source rect to be within the actual image */
    psx = sx;
@@ -295,8 +307,8 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
    /* if the input rect size < 0 dont render either */
    if ((sw <= 0) || (sh <= 0))
       return;
-   /* if the output is too big (8k arbitary limit here) dont bother */
-   if ((abs(dw) > 8192) || (abs(dh) > 8192))
+   /* if the output is too big (8k arbitrary limit here) dont bother */
+   if ((abs(dw) > X_MAX_DIM) || (abs(dh) > X_MAX_DIM))
       return;
    /* if we are scaling the image at all make a scaling buffer */
    if (!((sw == dw) && (sh == dh)))
@@ -424,7 +436,7 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
                     }
                   memcpy(buf, im->data + ((y + sy) * im->w),
                          im->w * hh * sizeof(DATA32));
-                  __imlib_DataCmodApply(buf, dw, hh, im->w - dw, NULL, cmod);
+                  __imlib_DataCmodApply(buf, im->w, hh, 0, NULL, cmod);
                   pointer = buf + sx;
                   jump = im->w - sw;
                }
@@ -467,7 +479,7 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
         XFreeGC(disp, gc);
         gc = 0;
      }
-   /* if we didnt have a gc... create it */
+   /* if we didn't have a gc... create it */
    if (!gc)
      {
         disp = d;
@@ -521,7 +533,6 @@ __imlib_RenderImageSkewed(Display * d, ImlibImage * im, Drawable w, Drawable m,
                           char dither_mask, int mat, ImlibColorModifier * cmod,
                           ImlibOp op)
 {
-   Context            *ct;
    int                 dx1, dy1, dx2, dy2, dw, dh, tsx, tsy;
    ImlibImage         *back;
 
@@ -572,11 +583,10 @@ __imlib_RenderImageSkewed(Display * d, ImlibImage * im, Drawable w, Drawable m,
         dy1 = 0;
      }
 
-   ct = __imlib_GetContext(d, v, cm, depth);
+   __imlib_GetContext(d, v, cm, depth);
 
    back = __imlib_CreateImage(dw, dh, NULL);
-   back->data = malloc(dw * dh * sizeof(DATA32));
-   memset(back->data, 0, dw * dh * sizeof(DATA32));
+   back->data = calloc(dw * dh, sizeof(DATA32));
    __imlib_GrabDrawableToRGBA(back->data, 0, 0, dw, dh, d, w, 0, v, cm,
                               depth, dx1, dy1, dw, dh, 0, 1);
 
@@ -590,4 +600,4 @@ __imlib_RenderImageSkewed(Display * d, ImlibImage * im, Drawable w, Drawable m,
    __imlib_FreeImage(back);
 }
 
-#endif
+#endif /* BUILD_X11 */
