@@ -226,18 +226,17 @@ colormod(Imlib_Image im, pIFunctionParam par)
 void
 init(struct imlib_filter_info *info)
 {
-   char               *filters[] = { "colormod" };
+   static const char  *const filters[] = { "colormod" };
    int                 i = (sizeof(filters) / sizeof(*filters));
 
    info->name = strdup("Tinting");
    info->author = strdup("Willem Monsuwe (willem@stack.nl)");
    info->description =
-       strdup("Provides most common color modification filters.");
+      strdup("Provides most common color modification filters.");
    info->num_filters = i;
    info->filters = malloc(sizeof(char *) * i);
    while (--i >= 0)
       info->filters[i] = strdup(filters[i]);
-
 }
 
 void
