@@ -4,19 +4,18 @@
 void
 init(struct imlib_filter_info *info)
 {
-   char               *filters[] = { "tint", "cool_text", "gradient" };
+   static const char  *const filters[] = { "tint", "cool_text", "gradient" };
    int                 i = 0;
 
    info->name = strdup("Test Filter");
    info->author = strdup("Chris Ross - Boris - chris@darkrock.co.uk");
    info->description =
-       strdup
-       ("This filter is used to show that the imlib2 filter system works!");
+      strdup
+      ("This filter is used to show that the imlib2 filter system works!");
    info->num_filters = 3;
    info->filters = malloc(sizeof(char *) * 3);
    for (i = 0; i < info->num_filters; i++)
       info->filters[i] = strdup(filters[i]);
-
 }
 
 void
@@ -47,7 +46,7 @@ exec(char *filter, void *im, pIFunctionParam params)
         w = imlib_image_get_width();
         h = imlib_image_get_height();
 
-        for (ptr = params; ptr != NULL; ptr = ptr->next)
+        for (ptr = params; ptr; ptr = ptr->next)
           {
              ASSIGN_DATA8("red", r);
              ASSIGN_DATA8("blue", b);
@@ -86,19 +85,23 @@ exec(char *filter, void *im, pIFunctionParam params)
         return imge;
      }
 
+#if 0                           /* Nothing useful here */
    if (strcmp(filter, "cool_text") == 0)
      {
         return imge;
      }
+
    if (strcmp(filter, "gradient") == 0)
      {
         int                 angle = 0;
 
-        for (ptr = params; ptr != NULL; ptr = ptr->next)
+        for (ptr = params; ptr; ptr = ptr->next)
           {
              ASSIGN_INT("angle", angle);
           }
         return imge;
      }
+#endif
+
    return imge;
 }
