@@ -38,14 +38,14 @@ load(ImlibImage * im, ImlibProgressFunction progress,
 
         /* if we haven't read the header before, set the header data */
         fread(buf, 1, PNG_BYTES_TO_CHECK, f);
-        if (!png_check_sig(buf, PNG_BYTES_TO_CHECK))
+        if (png_sig_cmp(buf, 0, PNG_BYTES_TO_CHECK))
           {
              fclose(f);
              return 0;
           }
         rewind(f);
         png_ptr =
-            png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
+           png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
         if (!png_ptr)
           {
              fclose(f);
@@ -58,7 +58,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
              fclose(f);
              return 0;
           }
-        if (setjmp(png_ptr->jmpbuf))
+        if (setjmp(png_jmpbuf(png_ptr)))
           {
              png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
              fclose(f);
@@ -71,7 +71,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
                      &interlace_type, NULL, NULL);
         im->w = (int)w32;
         im->h = (int)h32;
-        if ((w32 < 1) || (h32 < 1) || (w32 > 8192) || (h32 > 8192))
+        if (!IMAGE_DIMENSIONS_OK(w32, h32))
           {
              png_read_end(png_ptr, info_ptr);
              png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL);
@@ -110,7 +110,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
            png_set_palette_to_rgb(png_ptr);
         /* expand gray (w/reduced bits) -> 8-bit RGB if necessary */
         if ((color_type == PNG_COLOR_TYPE_GRAY) ||
-           (color_type == PNG_COLOR_TYPE_GRAY_ALPHA))
+            (color_type == PNG_COLOR_TYPE_GRAY_ALPHA))
           {
              png_set_gray_to_rgb(png_ptr);
              if (bit_depth < 8)
@@ -166,7 +166,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
         if (progress)
           {
              int                 y, count, prevy, pass, number_passes, per,
-                 nrows = 1;
+                nrows = 1;
 
              count = 0;
              number_passes = png_set_interlace_handling(png_ptr);
@@ -238,7 +238,7 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
    png_structp         png_ptr;
    png_infop           info_ptr;
    DATA32             *ptr;
-   int                 x, y, j;
+   int                 x, y, j, interlace;
    png_bytep           row_ptr, data = NULL;
    png_color_8         sig_bit;
    int                 pl = 0;
@@ -259,13 +259,13 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
         return 0;
      }
    info_ptr = png_create_info_struct(png_ptr);
-   if (info_ptr == NULL)
+   if (!info_ptr)
      {
         fclose(f);
         png_destroy_write_struct(&png_ptr, (png_infopp) NULL);
         return 0;
      }
-   if (setjmp(png_ptr->jmpbuf))
+   if (setjmp(png_jmpbuf(png_ptr)))
      {
         fclose(f);
         png_destroy_write_struct(&png_ptr, (png_infopp) & info_ptr);
@@ -274,11 +274,11 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
      }
 
    /* check whether we should use interlacing */
+   interlace = PNG_INTERLACE_NONE;
    if ((tag = __imlib_GetTag(im, "interlacing")) && tag->val)
      {
 #ifdef PNG_WRITE_INTERLACING_SUPPORTED
-          png_ptr->interlaced = PNG_INTERLACE_ADAM7;
-          num_passes = png_set_interlace_handling(png_ptr);
+        interlace = PNG_INTERLACE_ADAM7;
 #endif
      }
 
@@ -286,7 +286,7 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
    if (im->flags & F_HAS_ALPHA)
      {
         png_set_IHDR(png_ptr, info_ptr, im->w, im->h, 8,
-                     PNG_COLOR_TYPE_RGB_ALPHA, png_ptr->interlaced,
+                     PNG_COLOR_TYPE_RGB_ALPHA, interlace,
                      PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
 #ifdef WORDS_BIGENDIAN
         png_set_swap_alpha(png_ptr);
@@ -297,7 +297,7 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
    else
      {
         png_set_IHDR(png_ptr, info_ptr, im->w, im->h, 8, PNG_COLOR_TYPE_RGB,
-                     png_ptr->interlaced, PNG_COMPRESSION_TYPE_BASE,
+                     interlace, PNG_COMPRESSION_TYPE_BASE,
                      PNG_FILTER_TYPE_BASE);
         data = malloc(im->w * 3 * sizeof(char));
      }
@@ -333,7 +333,7 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
 #ifdef PNG_TEXT_SUPPORTED
         png_text            text;
 
-        text.key = "Imlib2-Comment";
+        text.key = (char *)"Imlib2-Comment";
         text.text = tag->data;
         text.compression = PNG_TEXT_COMPRESSION_zTXt;
         png_set_text(png_ptr, info_ptr, &(text), 1);
@@ -344,53 +344,57 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
    png_set_shift(png_ptr, &sig_bit);
    png_set_packing(png_ptr);
 
+#ifdef PNG_WRITE_INTERLACING_SUPPORTED
+   num_passes = png_set_interlace_handling(png_ptr);
+#endif
+
    for (pass = 0; pass < num_passes; pass++)
      {
-      ptr = im->data;
+        ptr = im->data;
 
-      for (y = 0; y < im->h; y++)
-        {
-           if (im->flags & F_HAS_ALPHA)
-              row_ptr = (png_bytep) ptr;
-           else
-             {
-                for (j = 0, x = 0; x < im->w; x++)
-                  {
-                     data[j++] = (ptr[x] >> 16) & 0xff;
-                     data[j++] = (ptr[x] >> 8) & 0xff;
-                     data[j++] = (ptr[x]) & 0xff;
-                  }
-                row_ptr = (png_bytep) data;
-             }
-           png_write_rows(png_ptr, &row_ptr, 1);
-           if (progress)
-             {
-                char                per;
-                int                 l;
+        for (y = 0; y < im->h; y++)
+          {
+             if (im->flags & F_HAS_ALPHA)
+                row_ptr = (png_bytep) ptr;
+             else
+               {
+                  for (j = 0, x = 0; x < im->w; x++)
+                    {
+                       data[j++] = (ptr[x] >> 16) & 0xff;
+                       data[j++] = (ptr[x] >> 8) & 0xff;
+                       data[j++] = (ptr[x]) & 0xff;
+                    }
+                  row_ptr = (png_bytep) data;
+               }
+             png_write_rows(png_ptr, &row_ptr, 1);
+             if (progress)
+               {
+                  char                per;
+                  int                 l;
 
-                per = 100 * (pass + y / (float) im->h) / num_passes;
-                if ((per - pper) >= progress_granularity)
-                  {
-                     l = y - pl;
-                     if (!progress(im, per, 0, (y - l), im->w, l))
-                       {
-                          if (data)
-                             free(data);
-                          png_write_end(png_ptr, info_ptr);
-                          png_destroy_write_struct(&png_ptr,
-                                                   (png_infopp) & info_ptr);
-                          png_destroy_info_struct(png_ptr,
-                                                  (png_infopp) & info_ptr);
-                          fclose(f);
-                          return 2;
-                       }
-                     pper = per;
-                     pl = y;
-                  }
-             }
-           ptr += im->w;
-        }
-    }
+                  per = 100 * (pass + y / (float)im->h) / num_passes;
+                  if ((per - pper) >= progress_granularity)
+                    {
+                       l = y - pl;
+                       if (!progress(im, per, 0, (y - l), im->w, l))
+                         {
+                            if (data)
+                               free(data);
+                            png_write_end(png_ptr, info_ptr);
+                            png_destroy_write_struct(&png_ptr,
+                                                     (png_infopp) & info_ptr);
+                            png_destroy_info_struct(png_ptr,
+                                                    (png_infopp) & info_ptr);
+                            fclose(f);
+                            return 2;
+                         }
+                       pper = per;
+                       pl = y;
+                    }
+               }
+             ptr += im->w;
+          }
+     }
    if (data)
       free(data);
    png_write_end(png_ptr, info_ptr);
@@ -411,18 +415,12 @@ save(ImlibImage * im, ImlibProgressFunction progress, char progress_granularity)
 void
 formats(ImlibLoader * l)
 {
-   /* this is the only bit you have to change... */
-   char               *list_formats[] = { "png" };
+   static const char  *const list_formats[] = { "png" };
+   int                 i;
 
-   /* don't bother changing any of this - it just reads this in and sets */
-   /* the struct values and makes copies */
-   {
-      int                 i;
+   l->num_formats = sizeof(list_formats) / sizeof(char *);
+   l->formats = malloc(sizeof(char *) * l->num_formats);
 
-      l->num_formats = (sizeof(list_formats) / sizeof(char *));
-      l->formats = malloc(sizeof(char *) * l->num_formats);
-
-      for (i = 0; i < l->num_formats; i++)
-         l->formats[i] = strdup(list_formats[i]);
-   }
+   for (i = 0; i < l->num_formats; i++)
+      l->formats[i] = strdup(list_formats[i]);
 }
